summaryrefslogtreecommitdiffstats
path: root/ash/ash_switches.cc
diff options
context:
space:
mode:
authorskuhne@chromium.org <skuhne@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-09-04 23:43:06 +0000
committerskuhne@chromium.org <skuhne@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-09-04 23:43:06 +0000
commit58fb96a133c3ab6f90650a98a45062104c79406a (patch)
tree8e8f338e337ef92d8f84df8420ee1bcd46d9bcb9 /ash/ash_switches.cc
parent1f923dd4d36d6cb37d6b4baf243ec897b58ff1cb (diff)
downloadchromium_src-58fb96a133c3ab6f90650a98a45062104c79406a.zip
chromium_src-58fb96a133c3ab6f90650a98a45062104c79406a.tar.gz
chromium_src-58fb96a133c3ab6f90650a98a45062104c79406a.tar.bz2
Enabling the new drag off shellf feature by default
BUG=284772 TEST=unittest Review URL: https://chromiumcodereview.appspot.com/23506029 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@221298 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/ash_switches.cc')
-rw-r--r--ash/ash_switches.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/ash/ash_switches.cc b/ash/ash_switches.cc
index 7f5f1d6..33d3672 100644
--- a/ash/ash_switches.cc
+++ b/ash/ash_switches.cc
@@ -90,8 +90,8 @@ const char kAshEnableBrightnessControl[] = "ash-enable-brightness-control";
// Enable the dock area on a desktop.
const char kAshEnableDockedWindows[] = "ash-enable-docked-windows";
-// Enable dragging items off the shelf to unpin them.
-const char kAshEnableDragOffShelf[] = "ash-enable-drag-off-shelf";
+// Disable dragging items off the shelf to unpin them.
+const char kAshDisableDragOffShelf[] = "ash-disable-drag-off-shelf";
// Enable immersive fullscreen mode, regardless of default setting.
const char kAshEnableImmersiveFullscreen[] = "ash-enable-immersive-fullscreen";
@@ -185,8 +185,8 @@ bool UseAlternateShelfLayout() {
}
bool UseDragOffShelf() {
- return CommandLine::ForCurrentProcess()->
- HasSwitch(ash::switches::kAshEnableDragOffShelf);
+ return !CommandLine::ForCurrentProcess()->
+ HasSwitch(ash::switches::kAshDisableDragOffShelf);
}
bool ShowShelfAlignmentMenu() {